==> qucs_0.0.15.orig.tar.gz: qucs-0.0.15/qucs-core/src/components/verilog/mux4to1.core.h <==
/*
 * mux4to1.core.h - device class definitions for mux4to1 module
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 */

#ifndef __mux4to1_H__
#define __mux4to1_H__

class mux4to1 : public circuit
{
 public:
  CREATOR (mux4to1);

  void initDC (void);
  void restartDC (void);
  void calcDC (void);
  void saveOperatingPoints (void);
  void loadOperatingPoints (void);
  void calcOperatingPoints (void);
  void initAC (void);
  void calcAC (nr_double_t);
  void initSP (void);
  void calcSP (nr_double_t);
  void calcNoiseAC (nr_double_t);
  void calcNoiseSP (nr_double_t);
  void initTR (void);
  void calcTR (nr_double_t);
  void initHB (int);
  void calcHB (int);
  
 private:
  void initVerilog (void);
  void calcVerilog (void);
  void initModel (void);
  void loadVariables (void);
  void initializeModel (void);
  void initializeInstance (void);
  void initialStep (void);
  void finalStep (void);
  matrix calcMatrixY (nr_double_t);
  matrix calcMatrixCy (nr_double_t);

 private:
  int doHB;
  int doAC;
  int doTR;

  nr_double_t _freq;
  nr_double_t _rhs[10];
  nr_double_t _qhs[10];
  nr_double_t _ghs[10];
  nr_double_t _chs[10];
  nr_double_t _jstat[10][10];
  nr_double_t _jdyna[10][10];
  nr_double_t _white_pwr[10][10];
  nr_double_t _flicker_pwr[10][10];
  nr_double_t _flicker_exp[10][10];
  nr_double_t _charges[10][10];
  nr_double_t _caps[10][10][10][10];

  // device model parameters
  nr_double_t TR;
  nr_double_t Delay;

  // global model variables
  double Rd;
  double Ccc;



};

#endif /* __mux4to1_H__ */

==> qucs-0.0.18.tar.gz: qucs-0.0.18/qucs-core/src/components/verilog/mux4to1.core.h <==
/*
 * mux4to1.core.h - device class definitions for mux4to1 module
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 */

#ifndef __mux4to1_H__
#define __mux4to1_H__

class mux4to1 : public qucs::circuit
{
 public:
  CREATOR (mux4to1);

  void initDC (void);
  void restartDC (void);
  void calcDC (void);
  void saveOperatingPoints (void);
  void loadOperatingPoints (void);
  void calcOperatingPoints (void);
  void initAC (void);
  void calcAC (nr_double_t);
  void initSP (void);
  void calcSP (nr_double_t);
  void calcNoiseAC (nr_double_t);
  void calcNoiseSP (nr_double_t);
  void initTR (void);
  void calcTR (nr_double_t);
  void initHB (int);
  void calcHB (int);

 private:
  void initVerilog (void);
  void calcVerilog (void);
  void initModel (void);
  void loadVariables (void);
  void initializeModel (void);
  void initializeInstance (void);
  void initialStep (void);
  void finalStep (void);
  qucs::matrix calcMatrixY (nr_double_t);
  qucs::matrix calcMatrixCy (nr_double_t);

 private:
  int doHB;
  int doAC;
  int doTR;

  nr_double_t _freq;
  nr_double_t _rhs[10];
  nr_double_t _qhs[10];
  nr_double_t _ghs[10];
  nr_double_t _chs[10];
  nr_double_t _jstat[10][10];
  nr_double_t _jdyna[10][10];
  nr_double_t _white_pwr[10][10];
  nr_double_t _flicker_pwr[10][10];
  nr_double_t _flicker_exp[10][10];
  nr_double_t _charges[10][10];
  nr_double_t _caps[10][10][10][10];

  // device model parameters
  nr_double_t TR;
  nr_double_t Delay;

  // global model variables
  double Rd;
  double Ccc;



};

#endif /* __mux4to1_H__ */
